@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2005';
+our $VERSION = '0.2006';
 
 use Algorithm::Combinatorics qw(variations_with_repetition);
 use MIDI::Util qw(dura_size);
@@ -424,6 +424,7 @@ sub combinatorial {
     $instrument ||= $self->snare;
 
     $opts->{negate}   ||= 0;
+    $opts->{count}    ||= 0;
     $opts->{beats}    ||= $self->beats;
     $opts->{repeat}   ||= 4;
     $opts->{duration} ||= $self->quarter;
@@ -440,12 +441,14 @@ sub combinatorial {
             variations_with_repetition( [ keys $opts->{vary}->%* ], $opts->{beats} );
 
     for my $pattern (@items) {
+        next if $pattern =~ /^0+$/;
+
         $pattern =~ tr/01/10/ if $opts->{negate};
 
         for ( 1 .. $opts->{repeat} ) {
             for my $bit ( split //, $pattern ) {
                 $opts->{vary}{$bit}->();
-                $self->counter( $self->counter + $size );
+                $self->counter( $self->counter + $size ) if $opts->{count};
             }
         }
     }
@@ -465,7 +468,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2005
+version 0.2006
 
 =head1 SYNOPSIS
 
@@ -833,7 +836,8 @@ Defaults:
 Play a beat pattern with the given B<instrument>, given by
 L<Algorithm::Combinatorics/variations_with_repetition>.
 
-This method accumulates beats in the object's B<counter> attribute.
+This method accumulates beats in the object's B<counter> attribute if
+the B<count> option is set..
 
 The B<vary> option is a hashref of coderefs, keyed by single character
 tokens, like the digits, 0-9.  The coderef durations should add up to
@@ -844,6 +848,7 @@ Defaults:
   instrument: snare
   Options:
     duration: quarter
+    count: 0
     negate: 0
     beats: beats
     repeat: 4
